summaryrefslogtreecommitdiffstats
path: root/kmail/bodyvisitor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/bodyvisitor.cpp')
-rw-r--r--kmail/bodyvisitor.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmail/bodyvisitor.cpp b/kmail/bodyvisitor.cpp
index 5c920584..337c843c 100644
--- a/kmail/bodyvisitor.cpp
+++ b/kmail/bodyvisitor.cpp
@@ -76,9 +76,9 @@ namespace KMail {
while ( (part = it.current()) != 0 )
{
++it;
- // skip this part if the parent part is already loading
- if ( part->parent() &&
- selected.tqcontains( part->parent() ) &&
+ // skip this part if the tqparent part is already loading
+ if ( part->tqparent() &&
+ selected.tqcontains( part->tqparent() ) &&
part->loadPart() )
continue;
@@ -114,9 +114,9 @@ namespace KMail {
headerCheck = false;
// check whether to load this part or not:
// look at the basic list, ask the subclass and check the parent
if ( mBasicList.tqcontains( part->originalContentTypeStr() ) ||
- parentNeedsLoading( part ) ||
+ tqparentNeedsLoading( part ) ||
addPartToList( part ) )
{
if ( part->typeStr() != "MULTIPART" ||
@@ -137,18 +137,18 @@ namespace KMail {
}
//-----------------------------------------------------------------------------
- bool BodyVisitor::parentNeedsLoading( KMMessagePart *msgPart )
+ bool BodyVisitor::tqparentNeedsLoading( KMMessagePart *msgPart )
{
KMMessagePart *part = msgPart;
while ( part )
{
- if ( part->parent() &&
- ( part->parent()->originalContentTypeStr() == "MULTIPART/SIGNED" ||
+ if ( part->tqparent() &&
+ ( part->tqparent()->originalContentTypeStr() == "MULTIPART/SIGNED" ||
( msgPart->originalContentTypeStr() == "APPLICATION/OCTET-STREAM" &&
- part->parent()->originalContentTypeStr() == "MULTIPART/ENCRYPTED" ) ) )
+ part->tqparent()->originalContentTypeStr() == "MULTIPART/ENCRYPTED" ) ) )
return true;
- part = part->parent();
+ part = part->tqparent();
}
return false;
}
@@ -114,9 +114,9 @@ namespace KMail {
headerCheck = false;
// check whether to load this part or not:
- // look at the basic list, ask the subclass and check the parent
+ // look at the basic list, ask the subclass and check the tqparent
if ( mBasicList.tqcontains( part->originalContentTypeStr() ) ||